==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/sl.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Čarovnik prvega zagona",
    "Add your profile information! For example your email is needed to reset your password." : "Dodajte svoje podatke o profilu! Na primer vaš e-poštni naslov je potreben za ponastavitev gesla.",
    "About" : "O programu",
    "Get the apps to sync your files" : "Pridobi programe za usklajevanje datotek",
    "Desktop client" : "Odjemalec za namizne računalnike",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "Connect your desktop apps to %s" : "Povežite namizne programe z %s",
    "Connect your calendar" : "Poveži svoj koledar",
    "Connect your contacts" : "Poveži svoje kontakte",
    "Access files via WebDAV" : "Dostopaj do datotek preko WebDAV",
    "Get help" : "Poišči pomoč",
    "The Nextcloud documentation for home users:" : "Dokumentacija NextCloud za uporabnike:",
    "User manual" : "Uporabniški priročnik",
    "Admin manual" : "Skrbniški priročnik",
    "Developer manual" : "Priročnik za razvijalce",
    "Start using Nextcloud" : "Začnite uporabljati Nextcloud",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Dostop in souporaba datotek, koledarja, stikov, elektronske pošte in drugih virov na napravi, pod vašimi pogoji!",
    "Connect your Calendar" : "Poveži svoj koledar",
    "Connect your Contacts" : "Poveži svoje stike",
    "Show First Run Wizard again" : "Ponovno prikaži čarovnika prvega zagona"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/sl.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Čarovnik prvega zagona",
    "Add your profile information! For example your email is needed to reset your password." : "Dodajte svoje podatke o profilu! Na primer vaš e-poštni naslov je potreben za ponastavitev gesla.",
    "About" : "O programu",
    "Get the apps to sync your files" : "Pridobi programe za usklajevanje datotek",
    "Desktop client" : "Odjemalec za namizne računalnike",
    "Android app" : "Odjemalec za Android",
    "iOS app" : "Odjemalec za iOS",
    "Connect your desktop apps to %s" : "Povežite namizne programe z %s",
    "Connect your calendar" : "Poveži svoj koledar",
    "Connect your contacts" : "Poveži svoje kontakte",
    "Access files via WebDAV" : "Dostopaj do datotek preko WebDAV",
    "Get help" : "Poišči pomoč",
    "The Nextcloud documentation for home users:" : "Dokumentacija NextCloud za uporabnike:",
    "User manual" : "Uporabniški priročnik",
    "Admin manual" : "Skrbniški priročnik",
    "Developer manual" : "Priročnik za razvijalce",
    "Start using Nextcloud" : "Začnite uporabljati Nextcloud",
    "Show First Run Wizard again" : "Ponovno prikaži čarovnika prvega zagona",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Dostop in souporaba datotek, koledarja, stikov, elektronske pošte in drugih virov na napravi, pod vašimi pogoji!"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
